@@ -1,6 +1,6 @@
 """Quickly add RapiDoc to FastAPI"""
 
-__version__ = "0.1.4"
+__version__ = "0.1.6"
 
 from fastapi.responses import HTMLResponse
 from fastapi import APIRouter
@@ -8,15 +8,15 @@ from fastapi import APIRouter
 
 def get_router(
     *,
-    openapi_url: str,
-    title: str,
+    openapi_url: str = "/openapi.json",
+    title: str = "FastAPI",
     rapidoc_js_url: str = "https://unpkg.com/rapidoc/dist/rapidoc-min.js",
     rapidoc_favicon_url: str = "https://fastapi.tiangolo.com/img/favicon.png",
     with_google_fonts: bool = True,
 ) -> APIRouter:
     router = APIRouter()
 
-    @router.get("/rapidcoc")
+    @router.get("/")
     def get_rapidoc_html() -> HTMLResponse:
         html = f"""
         <!doctype html> <!-- Important: must specify -->
